@@ -1,3 +1,19 @@
+/*
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+*/
+
 /*
  * Return values :
  *  -1 -> Cannot connect to the host
@@ -414,6 +430,8 @@ void CB_Execute_404(SU_PAnswer Ans,void *User)
 #endif /* __unix__ */
 }
 
+char *TranslateString(char *Strng,SMS_PProvider Pv);
+
 void CB_Execute_200(SU_PAnswer Ans,void *User)
 {
   SU_PList Ptr;
@@ -444,10 +462,10 @@ void CB_Execute_200(SU_PAnswer Ans,void *User)
         {
 #ifdef __unix__
           if(!SMS_Quiet)
-            printf("SmsSend Error : %s\n",S->Msg);
+            printf("SmsSend Error : %s\n",TranslateString(S->Msg,CurrentProviderRunning));
           exit(S->Error);
 #else /* !__unix__ */
-          Form1->StatusBar1->SimpleText = (AnsiString)"Error : " + (AnsiString)S->Msg;
+          Form1->StatusBar1->SimpleText = (AnsiString)"Error : " + (AnsiString)TranslateString(S->Msg,CurrentProviderRunning);
           Sms_ErrorCode = S->Error;
           return;
 #endif /* __unix__ */
@@ -457,7 +475,7 @@ void CB_Execute_200(SU_PAnswer Ans,void *User)
 #ifdef __unix__
           if(!SMS_Quiet)
 #endif /* __unix__ */
-            printf("Result : %s\n",S->Msg);
+            printf("Result : %s\n",TranslateString(S->Msg,CurrentProviderRunning));
         }
         Found = 1;
       }
@@ -471,10 +489,10 @@ void CB_Execute_200(SU_PAnswer Ans,void *User)
             {
 #ifdef __unix__
               if(!SMS_Quiet)
-                printf("SmsSend Error : %s\n",S->Msg);
+                printf("SmsSend Error : %s\n",TranslateString(S->Msg,CurrentProviderRunning));
               exit(S->Error);
 #else /* !__unix__ */
-              Form1->StatusBar1->SimpleText = (AnsiString)"Error : " + (AnsiString)S->Msg;
+              Form1->StatusBar1->SimpleText = (AnsiString)"Error : " + (AnsiString)TranslateString(S->Msg,CurrentProviderRunning);
               Sms_ErrorCode = S->Error;
               return;
 #endif /* __unix__ */
@@ -484,7 +502,7 @@ void CB_Execute_200(SU_PAnswer Ans,void *User)
 #ifdef __unix__
               if(!SMS_Quiet)
 #endif /* __unix__ */
-                printf("Result : %s\n",S->Msg);
+                printf("Result : %s\n",TranslateString(S->Msg,CurrentProviderRunning));
             }
             Found = 1;
           }
@@ -1934,6 +1952,7 @@ int main(int argc,char *argv[])
   char Cmd[1024];
   int Nargc = 1;
   char *Nargv[50];
+  bool OptDone = false;
 #ifdef _WIN32
   float fl; // This float is needed to force VC to link the math lib.. VC bug ;(
 
@@ -1966,7 +1985,7 @@ int main(int argc,char *argv[])
   while(i < argc)
   {
     j++;
-    if(argv[i][0] == '-')
+    if((argv[i][0] == '-') && (!OptDone))
     {
       if(strcasecmp(argv[i],"-update") == 0)
       {
@@ -1978,24 +1997,16 @@ int main(int argc,char *argv[])
         CheckForUpdateSmsSend();
         return 0;
       }
-      else if(strcasecmp(argv[i],"--help") == 0)
+      else if((strcasecmp(argv[i],"--help") == 0) || (strcasecmp(argv[i],"-h") == 0))
       {
         PrintHelp(NULL,false);
         return 0;
       }
-      else if(strcasecmp(argv[i],"-h") == 0)
-      {
-        PrintHelp(NULL,false);
-        return 0;
-      }
-      else if(strcasecmp(argv[i],"--version") == 0)
-      {
-        PrintHelp(NULL,true);
-        return 0;
-      }
-      else if(strcasecmp(argv[i],"-v") == 0)
+      else if((strcasecmp(argv[i],"--version") == 0) || (strcasecmp(argv[i],"-v") == 0))
       {
         PrintHelp(NULL,true);
+        printf("This is free software; see the source for copying conditions.  There is NO\n");
+        printf("warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\n");
         return 0;
       }
       else if(strcasecmp(argv[i],"-q") == 0)
@@ -2026,6 +2037,7 @@ int main(int argc,char *argv[])
     }
     else
     {
+      OptDone = true;
       Nargv[Nargc++] = argv[i];
       j--;
     }
